@@ -15,8 +15,8 @@
 
     You should have received a copy of the GNU Library General Public License
     along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+    Boston, MA 02111-1307, USA.
 */
 
 #include <config.h>
@@ -99,7 +99,7 @@ paragraph_style_get_store (GtkHTMLControlData *cd)
 		gtk_list_store_set (
 			cd->paragraph_style_store, &iter,
 			PARAGRAPH_STYLE_COLUMN_TEXT,
-			_(paragraph_style_data[ii].description),
+			gettext (paragraph_style_data[ii].description),
 			PARAGRAPH_STYLE_COLUMN_SENSITIVE,
 			cd->format_html ?
 				paragraph_style_data[ii].sensitive_html :
@@ -215,12 +215,3 @@ paragraph_style_update_store (GtkHTMLControlData *cd)
 			GTK_TREE_MODEL (store), &iter);
 	}
 }
-
-void
-paragraph_style_combobox_disconnect_html (GtkHTMLControlData *cd, GtkWidget *combo_box)
-{
-	g_return_if_fail (cd != NULL);
-	g_return_if_fail (cd->html != NULL);
-
-	g_signal_handlers_disconnect_by_func (cd->html, G_CALLBACK (current_paragraph_style_changed_cb), combo_box);
-}
